@@ -120,7 +120,7 @@ class Exceptions:
 
 class WorkDocsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html)
     """
 
@@ -139,7 +139,7 @@ class WorkDocsClient(BaseClient):
         Aborts the upload of the specified document version that was previously
         initiated by  InitiateDocumentVersionUpload.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#abort_document_version_upload)
         """
 
@@ -149,7 +149,7 @@ class WorkDocsClient(BaseClient):
         """
         Activates the specified user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.activate_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.activate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#activate_user)
         """
 
@@ -164,7 +164,7 @@ class WorkDocsClient(BaseClient):
         """
         Creates a set of permissions for the specified folder or document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#add_resource_permissions)
         """
 
@@ -172,7 +172,7 @@ class WorkDocsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#can_paginate)
         """
 
@@ -191,7 +191,7 @@ class WorkDocsClient(BaseClient):
         """
         Adds a new comment to the specified document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.create_comment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.create_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_comment)
         """
 
@@ -207,7 +207,7 @@ class WorkDocsClient(BaseClient):
         Adds one or more custom properties to the specified resource (a folder,
         document, or version).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_custom_metadata)
         """
 
@@ -217,7 +217,7 @@ class WorkDocsClient(BaseClient):
         """
         Creates a folder with the specified name and parent folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.create_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.create_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_folder)
         """
 
@@ -226,12 +226,10 @@ class WorkDocsClient(BaseClient):
     ) -> Dict[str, Any]:
         """
         Adds the specified list of labels to the given resource (a document or folder)
-        See also: `AWS API Documentation
-        <https://docs.aws.amazon.com/goto/WebAPI/workdocs-2016-05-01/CreateLabels>`_
-        **Request Syntax** response = client.create_labels( ResourceId='string',
-        Labels=[ ...
+        See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/workdocs-2016-05-01/CreateLabels).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.create_labels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.create_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_labels)
         """
 
@@ -246,7 +244,7 @@ class WorkDocsClient(BaseClient):
         """
         Configure Amazon WorkDocs to use Amazon SNS notifications.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_notification_subscription)
         """
 
@@ -266,7 +264,7 @@ class WorkDocsClient(BaseClient):
         """
         Creates a user in a Simple AD or Microsoft AD directory.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_user)
         """
 
@@ -275,7 +273,7 @@ class WorkDocsClient(BaseClient):
         Deactivates the specified user, which revokes the user's access to Amazon
         WorkDocs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#deactivate_user)
         """
 
@@ -285,7 +283,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the specified comment from the document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_comment)
         """
 
@@ -301,7 +299,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes custom metadata from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_custom_metadata)
         """
 
@@ -309,7 +307,7 @@ class WorkDocsClient(BaseClient):
         """
         Permanently deletes the specified document and its associated metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_document)
         """
 
@@ -317,7 +315,7 @@ class WorkDocsClient(BaseClient):
         """
         Permanently deletes the specified folder and its contents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder)
         """
 
@@ -325,7 +323,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the contents of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder_contents)
         """
 
@@ -340,7 +338,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the specified list of labels from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_labels)
         """
 
@@ -348,7 +346,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the specified subscription from the specified organization.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_notification_subscription)
         """
 
@@ -356,7 +354,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the specified user from a Simple AD or Microsoft AD directory.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_user)
         """
 
@@ -377,7 +375,7 @@ class WorkDocsClient(BaseClient):
         """
         Describes the user activities in a specified time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_activities)
         """
 
@@ -393,7 +391,7 @@ class WorkDocsClient(BaseClient):
         """
         List all the comments for the specified document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_comments)
         """
 
@@ -410,7 +408,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves the document versions for the specified document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_document_versions)
         """
 
@@ -430,7 +428,7 @@ class WorkDocsClient(BaseClient):
         Describes the contents of the specified folder, including its documents and
         subfolders.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_folder_contents)
         """
 
@@ -446,7 +444,7 @@ class WorkDocsClient(BaseClient):
         """
         Describes the groups specified by the query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_groups)
         """
 
@@ -456,7 +454,7 @@ class WorkDocsClient(BaseClient):
         """
         Lists the specified notification subscriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_notification_subscriptions)
         """
 
@@ -472,7 +470,7 @@ class WorkDocsClient(BaseClient):
         """
         Describes the permissions of a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_resource_permissions)
         """
 
@@ -483,7 +481,7 @@ class WorkDocsClient(BaseClient):
         Describes the current user's special folders; the `RootFolder` and the
         `RecycleBin`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_root_folders)
         """
 
@@ -504,7 +502,7 @@ class WorkDocsClient(BaseClient):
         """
         Describes the specified users.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.describe_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.describe_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_users)
         """
 
@@ -518,7 +516,7 @@ class WorkDocsClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#generate_presigned_url)
         """
 
@@ -527,7 +525,7 @@ class WorkDocsClient(BaseClient):
         Retrieves details of the current user for whom the authentication token was
         generated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_current_user)
         """
 
@@ -537,7 +535,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves details of a document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.get_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.get_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document)
         """
 
@@ -554,7 +552,7 @@ class WorkDocsClient(BaseClient):
         Retrieves the path information (the hierarchy from the root folder) for the
         requested document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_path)
         """
 
@@ -570,7 +568,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves version metadata for the specified document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_version)
         """
 
@@ -580,7 +578,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves the metadata of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.get_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.get_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder)
         """
 
@@ -597,7 +595,7 @@ class WorkDocsClient(BaseClient):
         Retrieves the path information (the hierarchy from the root folder) for the
         specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder_path)
         """
 
@@ -613,7 +611,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves a collection of resources, including folders and documents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.get_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.get_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_resources)
         """
 
@@ -632,7 +630,7 @@ class WorkDocsClient(BaseClient):
         """
         Creates a new document object and version object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#initiate_document_version_upload)
         """
 
@@ -642,7 +640,7 @@ class WorkDocsClient(BaseClient):
         """
         Removes all the permissions from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_all_resource_permissions)
         """
 
@@ -657,7 +655,7 @@ class WorkDocsClient(BaseClient):
         """
         Removes the permission for the specified principal from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_resource_permission)
         """
 
@@ -673,7 +671,7 @@ class WorkDocsClient(BaseClient):
         """
         Updates the specified attributes of a document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.update_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.update_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document)
         """
 
@@ -688,7 +686,7 @@ class WorkDocsClient(BaseClient):
         """
         Changes the status of the document version to ACTIVE.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document_version)
         """
 
@@ -704,7 +702,7 @@ class WorkDocsClient(BaseClient):
         """
         Updates the specified attributes of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.update_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.update_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_folder)
         """
 
@@ -725,7 +723,7 @@ class WorkDocsClient(BaseClient):
         Updates the specified attributes of the specified user, and grants or revokes
         administrative privileges to the Amazon WorkDocs site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_user)
         """
 
@@ -734,7 +732,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_activities"]
     ) -> DescribeActivitiesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
         """
 
@@ -743,7 +741,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_comments"]
     ) -> DescribeCommentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
         """
 
@@ -752,7 +750,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_document_versions"]
     ) -> DescribeDocumentVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
         """
 
@@ -761,14 +759,14 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_folder_contents"]
     ) -> DescribeFolderContentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_groups"]) -> DescribeGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
         """
 
@@ -777,7 +775,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_notification_subscriptions"]
     ) -> DescribeNotificationSubscriptionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
         """
 
@@ -786,7 +784,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_resource_permissions"]
     ) -> DescribeResourcePermissionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
         """
 
@@ -795,13 +793,13 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_root_folders"]
     ) -> DescribeRootFoldersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_users"]) -> DescribeUsersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
         """
